package com.chelvc.framework.base.exception;

import com.chelvc.framework.base.model.Result;
import com.chelvc.framework.base.util.HttpUtils;
import lombok.Getter;
import lombok.NonNull;
import org.springframework.http.HttpStatus;

/**
 * 框架异常
 *
 * @author Woody
 * @date 2023/1/1
 */
@Getter
public class FrameworkException extends RuntimeException {
    /**
     * 异常数据
     */
    private final Object data;

    /**
     * 异常状态
     */
    private final HttpStatus status;

    public FrameworkException() {
        this(HttpStatus.INTERNAL_SERVER_ERROR);
    }

    public FrameworkException(String message) {
        this(HttpStatus.INTERNAL_SERVER_ERROR, message);
    }

    public FrameworkException(@NonNull Result<?> result) {
        this(HttpUtils.getStatus(result.getCode()), result.getMessage(), result.getData(), null);
    }

    public FrameworkException(@NonNull HttpStatus status) {
        this(status, status.getReasonPhrase(), null, null);
    }

    public FrameworkException(@NonNull HttpStatus status, String message) {
        this(status, message, null, null);
    }

    public FrameworkException(@NonNull HttpStatus status, String message, Object data) {
        this(status, message, data, null);
    }

    public FrameworkException(@NonNull HttpStatus status, String message, Throwable cause) {
        this(status, message, null, cause);
    }

    public FrameworkException(@NonNull HttpStatus status, String message, Object data, Throwable cause) {
        super(message, cause);
        this.data = data;
        this.status = status;
    }
}
