package com.chelvc.framework.database.entity;

import java.io.Serializable;

import com.chelvc.framework.common.model.Tree;
import com.chelvc.framework.database.interceptor.PropertyUpdateInterceptor;

/**
 * 树形数据模型，序列号自动初始化以及所有下级节点序列号的自动更新
 *
 * @param <ID> 主键类型
 * @param <T>  子节点类型
 * @author Woody
 * @date 2023/1/1
 * @see BasicTreeEntity
 * @see PropertyUpdateInterceptor
 */
public interface TreeEntity<ID extends Serializable, T extends TreeEntity<ID, T>> extends Tree<ID, T>, Entity<ID> {
    /**
     * 获取序列号
     *
     * @return 序列号
     */
    String getSequence();

    /**
     * 设置序列号
     *
     * @param sequence 序列号
     */
    void setSequence(String sequence);
}
