package com.chelvc.framework.oauth.config;

import java.util.List;

import lombok.Data;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

/**
 * OAuth认证配置属性
 *
 * @author Woody
 * @date 2023/1/1
 * @see OauthConfigurer
 */
@Data
@Configuration
@ConfigurationProperties("oauth")
public class OauthProperties {
    /**
     * 令牌配置
     */
    private final Token token = new Token();

    /**
     * 资源配置
     */
    private final Resource resource = new Resource();

    /**
     * 令牌配置
     */
    @Data
    public static class Token {
        /**
         * 令牌手机号配置
         */
        private final Mobile mobile = new Mobile();

        /**
         * 令牌密钥对配置实例
         */
        private final KeyPair keyPair = new KeyPair();

        /**
         * 令牌签名密钥
         */
        private String secret;

        /**
         * 是否开启令牌复核
         */
        private boolean recheck;
    }

    /**
     * 令牌手机号配置
     */
    @Data
    public static class Mobile {
        /**
         * 是否加密
         */
        private boolean encrypted;
    }

    /**
     * 令牌密钥对配置
     */
    @Data
    public static class KeyPair {
        /**
         * 密钥别名
         */
        private String alias;

        /**
         * 资源路径
         */
        private String resource;

        /**
         * 密钥对密码
         */
        private String keyPairPassword;

        /**
         * 密钥存储密码
         */
        private String keyStorePassword;
    }

    /**
     * 资源配置
     */
    @Data
    public static class Resource {
        /**
         * 登录接口地址
         */
        private String login;

        /**
         * 注销接口地址
         */
        private String logout;

        /**
         * 拒绝的资源地址，多个地址使用","号隔开
         */
        private String deny;

        /**
         * 允许的资源地址，多个地址使用","号隔开
         */
        private String permit;

        /**
         * 忽略的资源地址，多个地址使用","号隔开
         */
        private String ignore;

        /**
         * 需要认证的资源地址，多个地址使用","号隔开
         */
        private String authenticated;

        /**
         * 资源访问控制列表
         */
        private List<Access> accesses;
    }

    /**
     * 资源访问控制
     */
    @Data
    public static class Access {
        /**
         * 资源地址，多个地址使用","号隔开
         */
        private String uri;

        /**
         * 客户端IP
         */
        private String ip;

        /**
         * 客户端角色
         */
        private String role;

        /**
         * 客户端权限
         */
        private String authority;

        /**
         * 访问许可
         */
        private String permission;
    }
}
