package com.chelvc.framework.oauth.token;

import java.time.Duration;

import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.oauth.context.OauthContextHolder;
import com.chelvc.framework.redis.context.RedisContextHolder;
import lombok.NonNull;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.oauth2.common.OAuth2AccessToken;
import org.springframework.security.oauth2.common.OAuth2RefreshToken;
import org.springframework.security.oauth2.provider.OAuth2Authentication;
import org.springframework.security.oauth2.provider.token.store.JwtAccessTokenConverter;
import org.springframework.security.oauth2.provider.token.store.JwtTokenStore;

/**
 * 基于Redis的令牌存储实现
 *
 * @author Woody
 * @date 2023/1/1
 */
@Slf4j
public class RedisTokenStore extends JwtTokenStore {
    private final RedisTemplate<String, Object> redisTemplate;

    public RedisTokenStore(@NonNull JwtAccessTokenConverter jwtAccessTokenConverter,
                           @NonNull RedisTemplate<String, Object> redisTemplate) {
        super(jwtAccessTokenConverter);
        this.redisTemplate = redisTemplate;
    }

    @Override
    public OAuth2RefreshToken readRefreshToken(String tokenValue) {
        OAuth2RefreshToken refreshToken = super.readRefreshToken(tokenValue);
        OauthContextHolder.setRefreshToken(refreshToken);
        return refreshToken;
    }

    @Override
    public void storeAccessToken(OAuth2AccessToken token, OAuth2Authentication authentication) {
        Object principal = authentication.getPrincipal();
        if (principal instanceof UserDetails) {
            principal = ((UserDetails) principal).getUsername();
        }
        String key = OauthContextHolder.buildAccessTokenKey(principal, SessionContextHolder.getTerminal());
        if (log.isDebugEnabled()) {
            log.debug("Saving redis token: {}", key);
        }
        Duration duration = RedisContextHolder.duration(token.getExpiration());
        this.redisTemplate.opsForValue().set(key, token.getValue(), duration);
    }
}
