package com.chelvc.framework.security.config;

import lombok.Data;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

/**
 * 信息安全配置属性
 *
 * @author Woody
 * @date 2023/1/1
 */
@Data
@Configuration
@ConfigurationProperties("security")
public class SecurityProperties {
    /**
     * 安全密钥
     */
    private String secret;

    /**
     * 是否启用
     */
    private boolean enabled;

    /**
     * 请求配置
     */
    private final Request request = new Request();

    /**
     * 数字签名
     */
    private final Signature signature = new Signature();

    /**
     * 请求配置
     */
    @Data
    public static class Request {
        /**
         * 放行资源地址，多个地址使用","号隔开
         */
        private String[] permit;

        /**
         * 必须校验的资源地址，多个地址使用","号隔开
         */
        private String[] require;

        /**
         * 允许的请求耗时（毫秒）
         */
        private long duration = 30 * 1000;
    }

    /**
     * 数字签名配置
     */
    @Data
    public static class Signature {
        /**
         * 放行资源地址，多个地址使用","号隔开
         */
        private String[] permit;

        /**
         * 必须校验的资源地址，多个地址使用","号隔开
         */
        private String[] require;
    }
}
