package com.chelvc.framework.security.context;

import com.chelvc.framework.base.context.ApplicationContextHolder;
import com.chelvc.framework.common.util.StringUtils;
import org.springframework.security.crypto.password.PasswordEncoder;

/**
 * @author Woody
 * @date 2023/1/1
 */
public class PasswordContextHolder {
    /**
     * 密码加解密处理器
     */
    private static PasswordEncoder PASSWORD_ENCODER;

    /**
     * 获取密码加解密处理器
     *
     * @return 密码加解密处理器
     */
    public static PasswordEncoder getPasswordEncoder() {
        if (PASSWORD_ENCODER == null) {
            synchronized (PasswordEncoder.class) {
                if (PASSWORD_ENCODER == null) {
                    PASSWORD_ENCODER = ApplicationContextHolder.getBean(PasswordEncoder.class);
                }
            }
        }
        return PASSWORD_ENCODER;
    }

    /**
     * 编码密码明文
     *
     * @param plaintext 密码文明
     * @param <T>       字符串类型
     * @return 密码密文
     */
    public static <T extends CharSequence> String encode(T plaintext) {
        return getPasswordEncoder().encode(plaintext);
    }

    /**
     * 判断密码是否匹配
     *
     * @param plaintext  密码文明
     * @param ciphertext 密码密文
     * @param <T>        字符串类型
     * @return true/false
     */
    public static <T extends CharSequence> boolean matches(T plaintext, String ciphertext) {
        return StringUtils.nonEmpty(plaintext) && StringUtils.nonEmpty(ciphertext)
                && getPasswordEncoder().matches(plaintext, ciphertext);
    }
}
