package com.chelvc.framework.upload.support;

import java.io.File;
import java.io.InputStream;

import com.chelvc.framework.common.util.FileUtils;
import com.chelvc.framework.common.util.StringUtils;
import com.chelvc.framework.upload.UploadHandler;
import com.chelvc.framework.upload.config.TencentUploadProperties;
import com.qcloud.cos.COSClient;
import com.qcloud.cos.model.ObjectMetadata;
import lombok.NonNull;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.stereotype.Component;

/**
 * 基于腾讯COS文件上传实现
 *
 * @author Woody
 * @date 2023/1/1
 */
@Component
@ConditionalOnBean(TencentUploadProperties.class)
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class TencentUploadHandler implements UploadHandler {
    private final COSClient client;
    private final TencentUploadProperties properties;

    /**
     * 将文件名称转换成URL地址
     *
     * @param filename 文件名称
     * @return URL地址
     */
    private String name2url(String filename) {
        return String.format(
                "https://%s.cos.%s.myqcloud.com/%s",
                this.properties.getBucket(), this.properties.getRegion(), filename
        );
    }

    @Override
    public String upload(@NonNull File file) {
        String suffix = FileUtils.getSuffix(file);
        String filename = StringUtils.uuid() + StringUtils.ifEmpty(suffix, name -> "." + name, StringUtils.EMPTY);
        this.client.putObject(this.properties.getBucket(), filename, file);
        return this.name2url(filename);
    }

    @Override
    public String upload(@NonNull InputStream stream, String suffix) {
        return this.upload(stream, suffix, FileUtils.getLength(stream));
    }

    @Override
    public String upload(@NonNull InputStream stream, String suffix, long length) {
        ObjectMetadata metadata = new ObjectMetadata();
        metadata.setContentLength(length);
        String filename = StringUtils.uuid() + StringUtils.ifEmpty(suffix, name -> "." + name, StringUtils.EMPTY);
        this.client.putObject(this.properties.getBucket(), filename, stream, metadata);
        return this.name2url(filename);
    }
}
